;****************************************************************************
;*                                                                          *
;* (c)2001 gabriele bellini                                                 *
;*                                                                          *
;* project_01a:                                                             *
;* a universal infrared remote controller for your Sony MD walkman          *
;*                                                                          *
;* -> source code for Microchip PIC16F84                                    *
;*                                                                          *
;* available from:                                                          *
;*                                                                          *
;* http://minidisconline.cjb.net                                            *
;*                                                                          *
;* please send me bugs reports and suggestions at:                          *
;*                                                                          *
;* minidisc@worldonline.it                                                  *
;*                                                                          *
;****************************************************************************
;*                                                                          *
;* filename:		ir_recv.asm                                         *
;* date:		05/05/2001                                          *
;* file version:	2.0                                                 *
;*                                                                          *
;* author:		gabriele bellini                                    *
;*                                                                          *
;****************************************************************************
;*                                                                          *
;* files required:	p16f84.inc                                          *
;*                      techni_1.inc                                        *
;*                                                                          *
;****************************************************************************
;*                                                                          *
;* notes: this is the first release of a new improved firmware version      *
;*        which will support various transmitter remotes. all you have to   *
;*        do is to specify an existing remote.inc file in the #INCLUDE      *
;*        directive below. if your remote transmitter is not included in    *
;*        the list, you can make a .inc file by yourself: open template.inc *
;*        file and insert the correct timing parameters and codes to make   *
;*        your remote transmitter compatible with the receiver              *
;*                                                                          *
;*        the default remote transmitter used is the Technics SL-XP505      *
;*        portable cd remote control transmitter                            *
;*                                                                          *
;****************************************************************************

	LIST		p=16F84		; list directive to define processor
	#INCLUDE	<p16F84.inc>	; processor specific variable
					; definitions

	#INCLUDE	"techni_1.inc"	; use this remote transmitter

	__CONFIG	_CP_OFF & _WDT_OFF & _PWRTE_ON & _XT_OSC

					; '__CONFIG' directive is used to
					; embed configuration data within
					; .asm file. the labels following
					; the directive are located in the
					; respective .inc file

;****************************************************************************
;* VARIABLES DEFINITIONS                                                    *
;****************************************************************************

_HEAD_P_LEN_MIN	EQU	_HEAD_P_LEN*(D'100'-_ERROR_TOL)/(D'100'*(D'10'+D'3'*(_HEADER_DELAY-D'1')))

					; this is the minimum value that
					; _COUNTER_REG must have when
					; calculated the header pulse length

_HEAD_P_LEN_MAX	EQU	_HEAD_P_LEN*(D'100'+_ERROR_TOL)/(D'100'*(D'10'+D'3'*(_HEADER_DELAY-D'1')))

					; this is the maximum value that
					; _COUNTER_REG must have when
					; calculated the header pulse length

_HEAD_S_LEN_MIN	EQU	_HEAD_S_LEN*(D'100'-_ERROR_TOL)/(D'100'*(D'10'+D'3'*(_HEADER_DELAY-D'1')))

					; this is the minimum value that
					; _COUNTER_REG must have when
					; calculated the header space length

_HEAD_S_LEN_MAX	EQU	_HEAD_S_LEN*(D'100'+_ERROR_TOL)/(D'100'*(D'10'+D'3'*(_HEADER_DELAY-D'1')))

					; this is the maximum value that
					; _COUNTER_REG must have when
					; calculated the header space length

_THRESHOLD	EQU	(_BIT_0_LEN+_BIT_1_LEN)/(D'2'*(D'10'+D'3'*(_BIT_DELAY-D'1')))

					; this is the threshold value which
					; determines whether the bit is
					; coded as 0 or 1



;SONY MINIDISC WALKMAN RESISTORS VALUES:

; notes: all values are obtained in this way:
; ((command resistor value)-(wiper resistance))/(potentiometer step)

_REW_VALUE	EQU	D'5'		; value to be stored in the digital
					; potentiometer for "rew" command
_PLAY_FF_VALUE	EQU	D'18'		; value to be stored in the digital
					; potentiometer for "play/ff" command
_PAUSE_VALUE	EQU	D'26'		; value to be stored in the digital
					; potentiometer for "pause" command
_STOP_VALUE	EQU	D'36'		; value to be stored in the digital
					; potentiometer for "stop" command
_VOL_LOW_VALUE	EQU	D'43'		; value to be stored in the digital
					; potentiometer for "vol-" command
_VOL_HIGH_VALUE	EQU	D'50'		; value to be stored in the digital
					; potentiometer for "vol+" command
_T_MARK_VALUE	EQU	D'61'		; value to be stored in the digital
					; potentiometer for "t.mark" command
_MODE_VALUE	EQU	D'71'		; value to be stored in the digital
					; potentiometer for "mode" command
_DISPLAY_VALUE	EQU	D'87'		; value to be stored in the digital
					; potentiometer for "display" command
_RECORD_VALUE	EQU	D'99'		; value to be stored in the digital
					; potentiometer for "record" command
_TEST_VALUE	EQU	D'122'		; value to be stored in the digital
					; potentiometer for "test" command

; OTHER:

_PRESS_TIME	EQU	D'3'		; this value will set the time of
					; switch activation when a command
					; is issued (multiply by 65ms)

;****************************************************************************
;* REGISTER DEFINITIONS                                                     *
;****************************************************************************

_W_TEMP		EQU	0x0C		; address of temporary W register
_STATUS_TEMP	EQU	0x0D		; address of temporary STATUS
					; register
_COUNTER_REG	EQU	0x0E		; address of first counter register
_DELAY_REG	EQU	0x0F		; address of second counter register
_AUX_REG	EQU	0x10		; address of auxiliary register
_POINTER_1	EQU	0x11		; address of first pointer register
_POINTER_2	EQU	0x12		; address of second pointer register
_BIT_COUNT	EQU	0x13		; address of bit counter register
_PRESS_COUNT	EQU	0x14		; address of button press counter
_POT_REG	EQU	0x15		; address of digital potentiometer
					; value register
_NEW_POT_REG	EQU	0x16		; address of new digital
					; potentiometer value register
_I2C_REG	EQU	0x17		; address of I2C byte register
_INPUT_BUFFER	EQU	0x18		; address of first byte of 6-bytes
					; input buffer
_COMMAND_BUFFER	EQU	0x1E		; address of first byte of 6-bytes
					; command buffer

; PORTA BIT ASSIGNMENTS:

_IR_BIT		EQU	1		; assign ir receiver bit in PORTA
_SDA_BIT	EQU	2		; assign SDA I2C bus bit in PORTA
_SCL_BIT	EQU	3		; assign SCL I2C bus bit in PORTA
_SPST_BIT	EQU	0		; assign switch control bit in PORTA

;****************************************************************************
;* MAIN PROGRAM                                                             *
;****************************************************************************

		ORG	0x2100			; initialize eeprom data

		de	"(c)2001 Gabriele Bellini: "
		de	"infrared remote controller for Sony MD"

		ORG	0x000			; processor reset vector:
		goto	_start			; go to program beginning

		ORG	0x004			; interrupt service routine:
		movwf	_W_TEMP			; save W and STATUS registers
		swapf	STATUS,W		; into temporary files
		movwf	_STATUS_TEMP		;

		bcf	INTCON,T0IF		; reset T0IF bit
		decfsz	_PRESS_COUNT,F		; decrement _PRESS_COUNT
		goto	_exit_enable		; if it reaches zero
		bcf	PORTA,_SPST_BIT		; then release the switch

		swapf	_STATUS_TEMP,W		; restore w and STATUS 
		movwf	STATUS			; register values before
		swapf	_W_TEMP,F		; the interrupt service
		swapf	_W_TEMP,W		; routine

		return				; return to program without
						; interrupt enabling

_exit_enable	swapf	_STATUS_TEMP,W		; restore w and STATUS
		movwf	STATUS			; register values before
		swapf	_W_TEMP,F		; the interrupt service
		swapf	_W_TEMP,W		; routine

		retfie				; return to program
						; and enable interrupts

_start		clrf	INTCON			; allow only TMR0 interrupt
		bsf	INTCON,T0IE		; now disabled
		bcf	PORTA,_SPST_BIT		; resistor circuit is open
		bsf	STATUS,RP0		; select register bank 1
		movlw	B'11010111'		; set prescaler value and
		movwf	OPTION_REG		; TMR0 settings
		bcf	TRISA,_SPST_BIT		; set _SPST_BIT (pin which
						; controls the analog switch)
						; as output

		bcf	STATUS,RP0		; return to register bank 0
		clrf	_POT_REG		; reset the digital
						; potentiometer value

_getcmd		movlw	_INPUT_BUFFER		; point to infrared string
		movwf	FSR			; buffer and clear all bytes
		movlw	D'6'			; of the buffer
		movwf	_COUNTER_REG		;
_clear		clrf	INDF			;
		incf	FSR,F			;
		decfsz	_COUNTER_REG,F	;
		goto	_clear			;
		movlw	_INPUT_BUFFER		; again point to infrared
		movwf	FSR			; string buffer

_begin		clrf	_BIT_COUNT		; reset the bit counter
		clrf	_COUNTER_REG		; reset counter register
_wait_ir_on_1	btfsc	PORTA,_IR_BIT		; wait until ir signal
		goto	_wait_ir_on_1		; is on (low signal on pin)

		if	_HEADER==_PRESENT	; assembled only if the
						; remote transmits header

_continue_1	movlw	_HEADER_DELAY		; routine to generate a basic 
		movwf	_DELAY_REG		; delay when calculating the
_loop_1		decfsz	_DELAY_REG,F		; header pulse length
		goto	_loop_1			;

		incf	_COUNTER_REG,F		; increment counter register
		btfsc	STATUS,Z		; if reached a timeout then
		goto	_begin			; wait for another header

		btfss	PORTA,_IR_BIT		; if ir signal is still on
		goto	_continue_1		; continue counting

		if	_HEADER_PULSE==_TESTED	; assembled only if the
						; header pulse length is
						; tested

		movf	_COUNTER_REG,W		; be sure that header pulse
		sublw	_HEAD_P_LEN_MAX		; length is equal or less
		btfss	STATUS,C		; than _HEAD_P_LEN_MAX and
		goto	_begin			; greater than
						; _HEAD_P_LEN_MIN
		movf	_COUNTER_REG,W		; if both conditions are
		sublw	_HEAD_P_LEN_MIN		; met, then continue the ir
		btfsc	STATUS,C		; string sampling, else
		goto	_begin			; wait for a valid header

		endif				;

		clrf	_COUNTER_REG		; reset counter register
_continue_2	movlw	_HEADER_DELAY		; routine to generate a basic 
		movwf	_DELAY_REG		; delay when calculating the
_loop_2		decfsz	_DELAY_REG,F		; header space length
		goto	_loop_2			;

		incf	_COUNTER_REG,F		; increment counter register
		btfsc	STATUS,Z		; if reached a timeout then
		goto	_begin			; wait for another header

		btfsc	PORTA,_IR_BIT		; if ir signal is still off
		goto	_continue_2		; continue counting

		if	_HEADER_SPACE==_TESTED	; assembled only if the
						; header space length is
						; tested

		movf	_COUNTER_REG,W		; be sure that header space
		sublw	_HEAD_S_LEN_MAX		; length is equal or less
		btfss	STATUS,C		; than _HEAD_S_LEN_MAX and
		goto	_begin			; greater than
						; _HEAD_S_LEN_MIN
		movf	_COUNTER_REG,W		; if both conditions are
		sublw	_HEAD_S_LEN_MIN		; met, then continue the ir
		btfsc	STATUS,C		; string sampling, else
		goto	_begin			; wait for a valid header

		endif

		endif


_repeat		clrf	_COUNTER_REG		; clear counter register
_wait_ir_on_2	btfsc	PORTA,_IR_BIT		; wait until ir signal
		goto	_wait_ir_on_2		; is on (low signal on bit)

		if	_CODING==_SPACE		; assembled if the remote
						; coding is SPACE CODED

_wait_ir_off_3	btfss	PORTA,_IR_BIT		; wait until ir signal
		goto	_wait_ir_off_3		; is off (high signal on bit)

		endif				;

_continue_3	movlw	_BIT_DELAY		; routine to generate a basic
		movwf	_DELAY_REG		; delay when calculating the
_loop_3		decfsz	_DELAY_REG,F		; bit pulse length
		goto	_loop_3			;

		incf	_COUNTER_REG,F		; increment counter register
		btfsc	STATUS,Z		; if reached a timeout then
		goto	_begin			; wait for another header

		if	_CODING==_SPACE		; assembled if the remote
						; coding is SPACE CODED
		btfsc	PORTA,_IR_BIT		; if ir signal is still off
						; continue counting
		endif

		if	_CODING==_PULSE		; assembled if the remote
						; coding is PULSE CODED
		btfss	PORTA,_IR_BIT		; if ir signal is still on
						; continue counting
		endif				;

		goto	_continue_3		;

		bcf	STATUS,C		; reset carry bit
		rlf	INDF,F			; ready to write bit
		movf	_COUNTER_REG,W		; if signal length is less
		sublw	_THRESHOLD		; than THRESHOLD then it will
		btfss	STATUS,C		; interpreted as "0"
		bsf	INDF,0			; otherwise it is "1"
		incf	_BIT_COUNT,F		; increment bit counter
		movf	_BIT_COUNT,W		; if all the string bits
		sublw	_STRING_LEN		; were received, then go
		btfsc	STATUS,Z		; comparing the received
		goto	_command		; string, otherwise, if
		movf	_BIT_COUNT,W		; 8 bits were written on the
		andlw	B'00000111'		; same byte, increment
		btfsc	STATUS,Z		; the received string
		incf	FSR,F			; pointer
		goto	_repeat			;

_command	movlw	_REW_1			; load the command buffer
		movwf	_COMMAND_BUFFER		; with the REW string
		movlw	_REW_2			; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_REW_3			;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_REW_4			;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_REW_5			;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_REW_6			;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_rew			; then execute the command

		movlw	_PLAY_FF_1		; load the command buffer
		movwf	_COMMAND_BUFFER		; with the PLAY_FF string
		movlw	_PLAY_FF_2		; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_PLAY_FF_3		;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_PLAY_FF_4		;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_PLAY_FF_5		;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_PLAY_FF_6		;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_play_ff		; then execute the command

		movlw	_PAUSE_1		; load the command buffer
		movwf	_COMMAND_BUFFER		; with the PAUSE string
		movlw	_PAUSE_2		; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_PAUSE_3		;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_PAUSE_4		;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_PAUSE_5		;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_PAUSE_6		;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_pause			; then execute the command

		movlw	_STOP_1			; load the command buffer
		movwf	_COMMAND_BUFFER		; with the STOP string
		movlw	_STOP_2			; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_STOP_3			;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_STOP_4			;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_STOP_5			;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_STOP_6			;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_stop			; then execute the command

		movlw	_VOL_LOW_1		; load the command buffer
		movwf	_COMMAND_BUFFER		; with the VOL_LOW string
		movlw	_VOL_LOW_2		; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_VOL_LOW_3		;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_VOL_LOW_4		;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_VOL_LOW_5		;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_VOL_LOW_6		;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_vol_low		; then execute the command

		movlw	_VOL_HIGH_1		; load the command buffer
		movwf	_COMMAND_BUFFER		; with the VOL_HIGH string
		movlw	_VOL_HIGH_2		; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_VOL_HIGH_3		;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_VOL_HIGH_4		;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_VOL_HIGH_5		;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_VOL_HIGH_6		;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_vol_high		; then execute the command

		movlw	_T_MARK_1		; load the command buffer
		movwf	_COMMAND_BUFFER		; with the T_MARK string
		movlw	_T_MARK_2		; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_T_MARK_3		;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_T_MARK_4		;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_T_MARK_5		;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_T_MARK_6		;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_t_mark			; then execute the command

		movlw	_MODE_1			; load the command buffer
		movwf	_COMMAND_BUFFER		; with the MODE string
		movlw	_MODE_2			; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_MODE_3			;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_MODE_4			;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_MODE_5			;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_MODE_6			;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_mode			; then execute the command

		movlw	_DISPLAY_1		; load the command buffer
		movwf	_COMMAND_BUFFER		; with the DISPLAY string
		movlw	_DISPLAY_2		; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_DISPLAY_3		;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_DISPLAY_4		;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_DISPLAY_5		;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_DISPLAY_6		;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_display		; then execute the command

		movlw	_RECORD_1		; load the command buffer
		movwf	_COMMAND_BUFFER		; with the RECORD string
		movlw	_RECORD_2		; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_RECORD_3		;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_RECORD_4		;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_RECORD_5		;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_RECORD_6		;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_record			; then execute the command

		movlw	_TEST_1			; load the command buffer
		movwf	_COMMAND_BUFFER		; with the TEST string
		movlw	_TEST_2			; command
		movwf	_COMMAND_BUFFER+1	;
		movlw	_TEST_3			;
		movwf	_COMMAND_BUFFER+2	;
		movlw	_TEST_4			;
		movwf	_COMMAND_BUFFER+3	;
		movlw	_TEST_5			;
		movwf	_COMMAND_BUFFER+4	;
		movlw	_TEST_6			;
		movwf	_COMMAND_BUFFER+5	;
		call	_buf_compare		; compare the received
		sublw	'E';qual?		; buffer with the command
		btfsc	STATUS,Z		; buffer, if they match
		goto	_test			; then execute the command

		goto	_getcmd			;

_rew		movlw	_REW_VALUE		; assign _REW_VALUE constant
		goto	_compare		; value to potentiometer file
_play_ff	movlw	_PLAY_FF_VALUE		; assign _PLAY_FF_VALUE constant
		goto	_compare		; value to potentiometer file
_pause		movlw	_PAUSE_VALUE		; assign _PAUSE_VALUE constant
		goto	_compare		; value to potentiometer file
_stop		movlw	_STOP_VALUE		; assign _STOP_VALUE constant
		goto	_compare		; value to potentiometer file
_vol_low	movlw	_VOL_LOW_VALUE		; assign _VOL_LOW_VALUE constant
		goto	_compare		; value to potentiometer file
_vol_high	movlw	_VOL_HIGH_VALUE		; assign _VOL_HIGH_VALUE constant
		goto	_compare		; value to potentiometer file
_t_mark		movlw	_T_MARK_VALUE		; assign _T_MARK_VALUE constant
		goto	_compare		; value to potentiometer file
_mode		movlw	_MODE_VALUE		; assign _MODE_VALUE constant
		goto	_compare		; value to potentiometer file
_display	movlw	_DISPLAY_VALUE		; assign _DISPLAY_VALUE constant
		goto	_compare		; value to potentiometer file
_record		movlw	_RECORD_VALUE		; assign _RECORD_VALUE constant
		goto	_compare		; value to potentiometer file
_test		movlw	_TEST_VALUE		; assign _TEST_VALUE constant
						; value to potentiometer file

_compare	movwf	_NEW_POT_REG		; store the value in _NEWCMD
		subwf	_POT_REG,W		; compare it with _POT_REG
		btfsc	STATUS,Z		; if they match skip serial
		goto	_close			; bus transmission, else
		movf	_NEW_POT_REG,W		; store new value in _POT_REG
		movwf	_POT_REG		; and send it to bus:

		call	_i2c_start		; begin bus transmission
		movlw	B'01010000'		; send digital potentiometer
		call	_i2c_send		; address to serial bus
		movlw	B'10101010'		; send command byte on bus:
		call	_i2c_send		; write on potentiometer 1
		movf	_POT_REG,W		; send the 8-bit value to be
		call	_i2c_send		; written to potentiometer 1
		bcf	PORTA,_SDA_BIT		; make sure that SDA is low
		bsf	STATUS,RP0		; forces SDA line to ground
		bcf	TRISA,_SDA_BIT		; before issue the end of
		bcf	STATUS,RP0		; serial bus transmission
		call	_i2c_delay		;
		call	_i2c_stop		; end bus transmission

_close		bsf	PORTA,_SPST_BIT		; close electric circuit
		movlw	_PRESS_TIME		; load _PRESS_COUNT with
		movwf	_PRESS_COUNT		; desired button press time
		clrf	TMR0			; reset TMR0 timer
		bcf	INTCON,T0IF		; reset interrupt flag and
		bsf	INTCON,GIE		; enable interrupts
		movlw	_INPUT_BUFFER		; point to first byte of ir
		movwf	FSR			; string buffer
		goto	_getcmd			; wait for a new command

;****************************************************************************
;* BUFFER COMPARING SUBROUTINE                                              *
;****************************************************************************

_buf_compare	movlw	_INPUT_BUFFER		; _POINTER_1 will point
		movwf	_POINTER_1		; to the input buffer and
		movlw	_COMMAND_BUFFER		; _POINTER_2 to the command
		movwf	_POINTER_2		; buffer
		movlw	D'6'			; 6 bytes will be compared
		movwf	_COUNTER_REG		;

_loop		movf	_POINTER_1,W		;
		movwf	FSR			;
		movf	INDF,W			;
		movwf	_AUX_REG		;

		movf	_POINTER_2,W		;
		movwf	FSR			;
		movf	INDF,W			;

		subwf	_AUX_REG,W		;
		btfss	STATUS,Z		;
		retlw	'N';ot equal		;
		incf	_POINTER_1,F		;
		incf	_POINTER_2,F		;
		decfsz	_COUNTER_REG,F	;
		goto	_loop			;
		retlw	'E';qual		;

;****************************************************************************
;* I2C BUS ROUTINES                                                         *
;****************************************************************************
;*                                                                          *
;* notes: SDA and SCL bit are always set to '0', we'll play with TRISA      *
;*        registers to make the OC outputs                                  *
;*                                                                          *
;****************************************************************************

_i2c_start	bcf	PORTA,_SDA_BIT		; start sequence on bus:
		bsf	STATUS,RP0		; make sure that SDA is low
		bcf	TRISA,_SDA_BIT		; pull down SDA line
		bcf	STATUS,RP0		;
		call	_i2c_delay		; wait some useconds
		bcf	PORTA,_SCL_BIT		; make sure that SCL is low
		bsf	STATUS,RP0		; then pull down also
		bcf	TRISA,_SCL_BIT		; the SCL line
		bcf	STATUS,RP0		;
		call	_i2c_delay		; wait some useconds
		return

_i2c_stop	bsf	STATUS,RP0		; stop sequence on bus:
		bsf	TRISA,_SCL_BIT		; release SCL line
		bcf	STATUS,RP0		;
		call	_i2c_delay		; wait some useconds
		bsf	STATUS,RP0		; then release also
		bsf	TRISA,_SDA_BIT		; the SDA line
		bcf	STATUS,RP0		; 
		call	_i2c_delay		; wait some useconds
		return

_i2c_send	movwf	_I2C_REG		; send a byte on bus and wait
		movlw	D'8'			; for acknowledge from slave:
		movwf	_COUNTER_REG		; load counter register
_i2c_bit	btfss	_I2C_REG,7		; check level of bit to be
		goto	_i2c_is_0		; transmitted: if it is '1'
		bsf	STATUS,RP0		; then release SDA line (set
		bsf	TRISA,_SDA_BIT		; to vcc level)
		bcf	STATUS,RP0		;
		goto	_i2c_continue		;
_i2c_is_0	bcf	PORTA,_SDA_BIT		; if it is a '0' then force
		bsf	STATUS,RP0		; SDA line to ground level
		bcf	TRISA,_SDA_BIT		;
		bcf	STATUS,RP0		;
_i2c_continue	call	_i2c_delay		; then act on SCL line:
		bsf	STATUS,RP0		;
		bsf	TRISA,_SCL_BIT		; first set it to high level
		bcf	STATUS,RP0		;
		call	_i2c_delay		; wait some useconds
		bcf	PORTA,_SCL_BIT		;
		bsf	STATUS,RP0		;
		bcf	TRISA,_SCL_BIT		; then set it to low level
		bcf	STATUS,RP0		;
		call	_i2c_delay		;
		rlf	_I2C_REG,F		; prepare next bit to send on
		decfsz	_COUNTER_REG,F		; bus, if 8 bit were sent
		goto	_i2c_bit		; then wait for acknowledge:
		bsf	STATUS,RP0		;
		bsf	TRISA,_SDA_BIT		; release SDA line and wait
		bcf	STATUS,RP0		; for slave response
_i2c_wait_l	btfsc	PORTA,_SDA_BIT		;
		goto	_i2c_wait_l		;
		call	_i2c_delay		;
		bsf	STATUS,RP0		;
		bsf	TRISA,_SCL_BIT		; send the SCL pulse
		bcf	STATUS,RP0		;
		call	_i2c_delay		;
		bcf	PORTA,_SCL_BIT		;
		bsf	STATUS,RP0		;
		bcf	TRISA,_SCL_BIT		;
		bcf	STATUS,RP0		;
_i2c_wait_h	btfss	PORTA,_SDA_BIT		; and wait for slave response
		goto	_i2c_wait_h		;
		call	_i2c_delay		;

		return

_i2c_delay	nop				; nops to generate delay
		nop				; for bus communications
		nop
		nop
		nop
		nop

		return

		END
