;****************************************************************************
;*                                                                          *
;* (c)2001 gabriele bellini                                                 *
;*                                                                          *
;* project_01a:                                                             *
;* a universal infrared remote controller for your Sony MD walkman          *
;*                                                                          *
;* -> source code for Microchip PIC16F84                                    *
;*                                                                          *
;* available from:                                                          *
;*                                                                          *
;* http://minidisconline.cjb.net                                            *
;*                                                                          *
;* please send me bugs reports and suggestions at:                          *
;*                                                                          *
;* minidisc@worldonline.it                                                  *
;*                                                                          *
;****************************************************************************
;*                                                                          *
;* filename:		techni_1.inc                                        *
;* date:		05/05/2001                                          *
;* file version:	1.0                                                 *
;*                                                                          *
;* author:		gabriele bellini                                    *
;*                                                                          *
;****************************************************************************
;*                                                                          *
;* notes: this .inc file contains all the settings to use the infrared      *
;*        receiver with the                                                 *
;*                                                                          *
;*        TECHNICS SL-XP505 PORTABLE CD PLAYER remote control transmitter   *
;*                                                                          *
;* brand:      TECHNICS                                                     *
;* category:   CD                                                           *
;*                                                                          *
;* NB: the receiver will also work with other transmitters of the same      *
;*     brand and category listed above                                      *
;*                                                                          *
;* transmitter model ID: EURSBFA06N                                         *
;*                                                                          *
;* keys assignements:    +----------------+---------------+                 *
;*                       | command on MD  | key on remote |                 *
;*                       +----------------+---------------+                 *
;*                       | rew/track-     | rew/track-    |                 *
;*                       | play/ff/track+ | ff/track+     |                 *
;*                       | pause          | play/pause    |                 *
;*                       | stop           | stop          |                 *
;*                       | vol-           | level-        |                 *
;*                       | vol+           | level+        |                 *
;*                       | track mark     | N.A.          |                 *
;*                       | mode           | repeat        |                 *
;*                       | display        | N.A.          |                 *
;*                       | record         | m.scan        |                 *
;*                       | test mode      | N.A.          |                 *
;*                       +----------------+---------------+                 *
;*                                                                          *
;*                       N.A.: the function hasn't a key on remote          *
;*                             transmitter (Not Assigned)                   *
;*                                                                          *
;****************************************************************************


;****************************************************************************
;* INFRARED REMOTE TRANSMITTER TIMING SETTINGS                              *
;****************************************************************************

_NOT_PRESENT	EQU	0		; these constants are useful to
_PRESENT	EQU	1		; understand how the conditionally
_NOT_TESTED	EQU	0		; assembled code blocks are processed
_TESTED		EQU	1		; when compiling the source code
_SPACE		EQU	0		; with Microchip's MPASM
_PULSE		EQU	1		;


_HEADER		EQU	_PRESENT	; this remote transmits header

_HEADER_PULSE	EQU	_TESTED		; test header pulse length

_HEADER_SPACE	EQU	_NOT_TESTED	; ignore header space length

_CODING		EQU	_SPACE		; this remote uses this coding

_HEAD_P_LEN	EQU	D'4000'		; this is the value in microseconds
					; of the header pulse length

_HEAD_S_LEN	EQU	D'1600'		; this is the value in microseconds
					; of the header space length

_BIT_0_LEN	EQU	D'400'		; this is the value in microseconds
					; of the pulse (or space) interval
					; which is interpreted as "0" bit

_BIT_1_LEN	EQU	D'1200'		; this is the value in microseconds
					; of the pulse (or space) interval
					; which is interpreted as "1" bit

_STRING_LEN	EQU	D'48'		; this is the number of bits sent by
					; the remote transmitter for each
					; command

_ERROR_TOL	EQU	D'20'		; the receiver will issue commands
					; to the MD unit only if the received
					; header pulse (and/or space) has a
					; length included in the range:
					; 
					; _HEAD_P_LEN +/- _ERROR_TOL %
					; (and/or
					; _HEAD_S_LEN +/- _ERROR_TOL %)

_BIT_DELAY	EQU	D'1'		; this value will produce a delay
					; when receiving the bit pulse


_HEADER_DELAY	EQU	D'12'		; this value will produce a delay
					; when receiving the header pulse

;****************************************************************************
;* INFRARED REMOTE TRANSMITTER CODES                                        *
;****************************************************************************

_REW_1		EQU	0x40		; 1st "rew" command byte
_REW_2		EQU	0x04		; 2nd "rew" command byte
_REW_3		EQU	0x05		; 3rd "rew" command byte
_REW_4		EQU	0x50		; 4th "rew" command byte
_REW_5		EQU	0x92		; 5th "rew" command byte
_REW_6		EQU	0xC7		; 6th "rew" command byte
_PLAY_FF_1	EQU	0x40		; 1st "play/ff" command byte
_PLAY_FF_2	EQU	0x04		; 2nd "play/ff" command byte
_PLAY_FF_3	EQU	0x05		; 3rd "play/ff" command byte
_PLAY_FF_4	EQU	0x50		; 4th "play/ff" command byte
_PLAY_FF_5	EQU	0x52		; 5th "play/ff" command byte
_PLAY_FF_6	EQU	0x07		; 6th "play/ff" command byte
_PAUSE_1	EQU	0x40		; 1st "pause" command byte
_PAUSE_2	EQU	0x04		; 2nd "pause" command byte
_PAUSE_3	EQU	0x05		; 3rd "pause" command byte
_PAUSE_4	EQU	0x50		; 4th "pause" command byte
_PAUSE_5	EQU	0x50		; 5th "pause" command byte
_PAUSE_6	EQU	0x05		; 6th "pause" command byte
_STOP_1		EQU	0x40		; 1st "stop" command byte
_STOP_2		EQU	0x04		; 2nd "stop" command byte
_STOP_3		EQU	0x05		; 3rd "stop" command byte
_STOP_4		EQU	0x50		; 4th "stop" command byte
_STOP_5		EQU	0x00		; 5th "stop" command byte
_STOP_6		EQU	0x55		; 6th "stop" command byte
_VOL_LOW_1	EQU	0x40		; 1st "vol-" command byte
_VOL_LOW_2	EQU	0x04		; 2nd "vol-" command byte
_VOL_LOW_3	EQU	0x05		; 3rd "vol-" command byte
_VOL_LOW_4	EQU	0x50		; 4th "vol-" command byte
_VOL_LOW_5	EQU	0x84		; 5th "vol-" command byte
_VOL_LOW_6	EQU	0xD1		; 6th "vol-" command byte
_VOL_HIGH_1	EQU	0x40		; 1st "vol+" command byte
_VOL_HIGH_2	EQU	0x04		; 2nd "vol+" command byte
_VOL_HIGH_3	EQU	0x05		; 3rd "vol+" command byte
_VOL_HIGH_4	EQU	0x50		; 4th "vol+" command byte
_VOL_HIGH_5	EQU	0x04		; 5th "vol+" command byte
_VOL_HIGH_6	EQU	0x51		; 6th "vol+" command byte
_T_MARK_1	EQU	0xFF		; 1st "t.mark" command byte
_T_MARK_2	EQU	0xFF		; 2nd "t.mark" command byte
_T_MARK_3	EQU	0xFF		; 3rd "t.mark" command byte
_T_MARK_4	EQU	0xFF		; 4th "t.mark" command byte
_T_MARK_5	EQU	0xFF		; 5th "t.mark" command byte
_T_MARK_6	EQU	0xFF		; 6th "t.mark" command byte
_MODE_1		EQU	0x40		; 1st "mode" command byte
_MODE_2		EQU	0x04		; 2nd "mode" command byte
_MODE_3		EQU	0x05		; 3rd "mode" command byte
_MODE_4		EQU	0x50		; 4th "mode" command byte
_MODE_5		EQU	0xE2		; 5th "mode" command byte
_MODE_6		EQU	0xB7		; 6th "mode" command byte
_DISPLAY_1	EQU	0xFF		; 1st "display" command byte
_DISPLAY_2	EQU	0xFF		; 2nd "display" command byte
_DISPLAY_3	EQU	0xFF		; 3rd "display" command byte
_DISPLAY_4	EQU	0xFF		; 4th "display" command byte
_DISPLAY_5	EQU	0xFF		; 5th "display" command byte
_DISPLAY_6	EQU	0xFF		; 6th "display" command byte
_RECORD_1	EQU	0x40		; 1st "record" command byte
_RECORD_2	EQU	0x04		; 2nd "record" command byte
_RECORD_3	EQU	0x05		; 3rd "record" command byte
_RECORD_4	EQU	0x50		; 4th "record" command byte
_RECORD_5	EQU	0x62		; 5th "record" command byte
_RECORD_6	EQU	0x37		; 6th "record" command byte
_TEST_1		EQU	0xFF		; 1st "test" command byte
_TEST_2		EQU	0xFF		; 2nd "test" command byte
_TEST_3		EQU	0xFF		; 3rd "test" command byte
_TEST_4		EQU	0xFF		; 4th "test" command byte
_TEST_5		EQU	0xFF		; 5th "test" command byte
_TEST_6		EQU	0xFF		; 6th "test" command byte
