;****************************************************************************
;*                                                                          *
;* (c)2001 gabriele bellini                                                 *
;*                                                                          *
;* project_01a:                                                             *
;* a universal infrared remote controller for your Sony MD walkman          *
;*                                                                          *
;* -> source code for Microchip PIC16F84                                    *
;*                                                                          *
;* available from:                                                          *
;*                                                                          *
;* http://minidisconline.cjb.net                                            *
;*                                                                          *
;* please send me bugs reports and suggestions at:                          *
;*                                                                          *
;* minidisc@worldonline.it                                                  *
;*                                                                          *
;****************************************************************************
;*                                                                          *
;* filename:		template.inc                                        *
;* date:		05/05/2001                                          *
;* file version:	1.0                                                 *
;*                                                                          *
;* author:		gabriele bellini                                    *
;*                                                                          *
;****************************************************************************
;*                                                                          *
;* notes: this .inc file contains all the settings to use the infrared      *
;*        receiver with the                                                 *
;*                                                                          *
;*        ??? remote control transmitter                                    *
;*                                                                          *
;* brand:      ???                                                          *
;* category:   ???                                                          *
;*                                                                          *
;* NB: the receiver will also work with other transmitters of the same      *
;*     brand and category listed above                                      *
;*                                                                          *
;* transmitter model ID: ???                                                *
;*                                                                          *
;* keys assignements:    +----------------+---------------+                 *
;*                       | command on MD  | key on remote |                 *
;*                       +----------------+---------------+                 *
;*                       | rew/track-     | ???           |                 *
;*                       | play/ff/track+ | ???           |                 *
;*                       | pause          | ???           |                 *
;*                       | stop           | ???           |                 *
;*                       | vol-           | ???           |                 *
;*                       | vol+           | ???           |                 *
;*                       | track mark     | ???           |                 *
;*                       | mode           | ???           |                 *
;*                       | display        | ???           |                 *
;*                       | record         | ???           |                 *
;*                       | test mode      | ???           |                 *
;*                       +----------------+---------------+                 *
;*                                                                          *
;*                       N.A.: the function hasn't a key on remote          *
;*                             transmitter (Not Assigned)                   *
;*                                                                          *
;****************************************************************************


;****************************************************************************
;* INFRARED REMOTE TRANSMITTER TIMING SETTINGS                              *
;****************************************************************************

_NOT_PRESENT	EQU	0		; these constants are useful to
_PRESENT	EQU	1		; understand how the conditionally
_NOT_TESTED	EQU	0		; assembled code blocks are processed
_TESTED		EQU	1		; when compiling the source code
_SPACE		EQU	0		; with Microchip's MPASM
_PULSE		EQU	1		;


_HEADER		EQU	???		; type _PRESENT if your remote
					; transmits header first, type
					; _NOT_PRESENT if the transmission is
					; headerless

_HEADER_PULSE	EQU	???		; type _TESTED if you want to test
					; the header pulse length when
					; received, _NOT_TESTED if you want
					; to ignore the header pulse lenght

_HEADER_SPACE	EQU	???		; type _TESTED if you want to test
					; the header space length when
					; received, _NOT_TESTED if you want
					; to ignore the header pulse lenght

_CODING		EQU	???		; type the correct transmission
					; coding of your remote transmitter:
					; _SPACE for space modulated coding
					; _PULSE for pulse modulated coding

_HEAD_P_LEN	EQU	D'???'		; insert the value in microseconds
					; of the header pulse length

_HEAD_S_LEN	EQU	D'???'		; insert the value in microseconds
					; of the header space length

_BIT_0_LEN	EQU	D'???'		; insert the value in microseconds
					; of the pulse (if the transmission
					; is pulse modulated) or space (if
					; the transmission is space
					; modulated) interval which is
					; interpreted as "0" bit

_BIT_1_LEN	EQU	D'???'		; insert the value in microseconds
					; of the pulse (if the transmission
					; is pulse modulated) or space (if
					; the transmission is space
					; modulated) interval which is
					; interpreted as "1" bit

_STRING_LEN	EQU	D'??'		; insert the number of bits sent by
					; the remote transmitter when issuing
					; a command

_ERROR_TOL	EQU	D'20'		; the receiver will issue commands
					; to the MD unit only if the received
					; header pulse (and/or space) has a
					; length included in the range:
					; 
					; _HEAD_P_LEN +/- _ERROR_TOL %
					; (and/or
					; _HEAD_S_LEN +/- _ERROR_TOL %)

_BIT_DELAY	EQU	D'1'		; this value will produce a delay
					; when receiving the bit pulse


_HEADER_DELAY	EQU	D'12'		; this value will produce a delay
					; when receiving the header pulse

;****************************************************************************
;* INFRARED REMOTE TRANSMITTER CODES                                        *
;****************************************************************************

_REW_1		EQU	0xFF		; 1st "rew" command byte
_REW_2		EQU	0xFF		; 2nd "rew" command byte
_REW_3		EQU	0xFF		; 3rd "rew" command byte
_REW_4		EQU	0xFF		; 4th "rew" command byte
_REW_5		EQU	0xFF		; 5th "rew" command byte
_REW_6		EQU	0xFF		; 6th "rew" command byte
_PLAY_FF_1	EQU	0xFF		; 1st "play/ff" command byte
_PLAY_FF_2	EQU	0xFF		; 2nd "play/ff" command byte
_PLAY_FF_3	EQU	0xFF		; 3rd "play/ff" command byte
_PLAY_FF_4	EQU	0xFF		; 4th "play/ff" command byte
_PLAY_FF_5	EQU	0xFF		; 5th "play/ff" command byte
_PLAY_FF_6	EQU	0xFF		; 6th "play/ff" command byte
_PAUSE_1	EQU	0xFF		; 1st "pause" command byte
_PAUSE_2	EQU	0xFF		; 2nd "pause" command byte
_PAUSE_3	EQU	0xFF		; 3rd "pause" command byte
_PAUSE_4	EQU	0xFF		; 4th "pause" command byte
_PAUSE_5	EQU	0xFF		; 5th "pause" command byte
_PAUSE_6	EQU	0xFF		; 6th "pause" command byte
_STOP_1		EQU	0xFF		; 1st "stop" command byte
_STOP_2		EQU	0xFF		; 2nd "stop" command byte
_STOP_3		EQU	0xFF		; 3rd "stop" command byte
_STOP_4		EQU	0xFF		; 4th "stop" command byte
_STOP_5		EQU	0xFF		; 5th "stop" command byte
_STOP_6		EQU	0xFF		; 6th "stop" command byte
_VOL_LOW_1	EQU	0xFF		; 1st "vol-" command byte
_VOL_LOW_2	EQU	0xFF		; 2nd "vol-" command byte
_VOL_LOW_3	EQU	0xFF		; 3rd "vol-" command byte
_VOL_LOW_4	EQU	0xFF		; 4th "vol-" command byte
_VOL_LOW_5	EQU	0xFF		; 5th "vol-" command byte
_VOL_LOW_6	EQU	0xFF		; 6th "vol-" command byte
_VOL_HIGH_1	EQU	0xFF		; 1st "vol+" command byte
_VOL_HIGH_2	EQU	0xFF		; 2nd "vol+" command byte
_VOL_HIGH_3	EQU	0xFF		; 3rd "vol+" command byte
_VOL_HIGH_4	EQU	0xFF		; 4th "vol+" command byte
_VOL_HIGH_5	EQU	0xFF		; 5th "vol+" command byte
_VOL_HIGH_6	EQU	0xFF		; 6th "vol+" command byte
_T_MARK_1	EQU	0xFF		; 1st "t.mark" command byte
_T_MARK_2	EQU	0xFF		; 2nd "t.mark" command byte
_T_MARK_3	EQU	0xFF		; 3rd "t.mark" command byte
_T_MARK_4	EQU	0xFF		; 4th "t.mark" command byte
_T_MARK_5	EQU	0xFF		; 5th "t.mark" command byte
_T_MARK_6	EQU	0xFF		; 6th "t.mark" command byte
_MODE_1		EQU	0xFF		; 1st "mode" command byte
_MODE_2		EQU	0xFF		; 2nd "mode" command byte
_MODE_3		EQU	0xFF		; 3rd "mode" command byte
_MODE_4		EQU	0xFF		; 4th "mode" command byte
_MODE_5		EQU	0xFF		; 5th "mode" command byte
_MODE_6		EQU	0xFF		; 6th "mode" command byte
_DISPLAY_1	EQU	0xFF		; 1st "display" command byte
_DISPLAY_2	EQU	0xFF		; 2nd "display" command byte
_DISPLAY_3	EQU	0xFF		; 3rd "display" command byte
_DISPLAY_4	EQU	0xFF		; 4th "display" command byte
_DISPLAY_5	EQU	0xFF		; 5th "display" command byte
_DISPLAY_6	EQU	0xFF		; 6th "display" command byte
_RECORD_1	EQU	0xFF		; 1st "record" command byte
_RECORD_2	EQU	0xFF		; 2nd "record" command byte
_RECORD_3	EQU	0xFF		; 3rd "record" command byte
_RECORD_4	EQU	0xFF		; 4th "record" command byte
_RECORD_5	EQU	0xFF		; 5th "record" command byte
_RECORD_6	EQU	0xFF		; 6th "record" command byte
_TEST_1		EQU	0xFF		; 1st "test" command byte
_TEST_2		EQU	0xFF		; 2nd "test" command byte
_TEST_3		EQU	0xFF		; 3rd "test" command byte
_TEST_4		EQU	0xFF		; 4th "test" command byte
_TEST_5		EQU	0xFF		; 5th "test" command byte
_TEST_6		EQU	0xFF		; 6th "test" command byte
